==> haskell-test-framework-hunit-0.3.0.2-772-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-hunit
version:              0.3.0.2
visibility:           public
id:                   test-framework-hunit-0.3.0.2-7Er2VSqceFQKTUu3QzBEVh
key:                  test-framework-hunit-0.3.0.2-7Er2VSqceFQKTUu3QzBEVh
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://batterseapower.github.io/test-framework/
synopsis:             HUnit support for the test-framework package.
description:          HUnit support for the test-framework package.
category:             Testing
abi:                  0d1ac5fddad4a95d3e117b8e23493f0a
exposed:              True
exposed-modules:      Test.Framework.Providers.HUnit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-hunit
hs-libraries:         HStest-framework-hunit-0.3.0.2-7Er2VSqceFQKTUu3QzBEVh
depends:
    HUnit-1.6.2.0-3CdzA0NfUMg32heVGtndy4 base-4.17.2.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    test-framework-0.8.2.2-45NM0HcE00tABumruyxSqR

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-hunit-0.3.0.2-773-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-hunit
version:              0.3.0.2
visibility:           public
id:                   test-framework-hunit-0.3.0.2-66O3YPm7X829lCZRFE64GG
key:                  test-framework-hunit-0.3.0.2-66O3YPm7X829lCZRFE64GG
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://batterseapower.github.io/test-framework/
synopsis:             HUnit support for the test-framework package.
description:          HUnit support for the test-framework package.
category:             Testing
abi:                  ee089f73a89addbc01385e748326690c
exposed:              True
exposed-modules:      Test.Framework.Providers.HUnit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-hunit
hs-libraries:         HStest-framework-hunit-0.3.0.2-66O3YPm7X829lCZRFE64GG
depends:
    HUnit-1.6.2.0-3CdzA0NfUMg32heVGtndy4 base-4.17.2.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    test-framework-0.8.2.2-FfnVJ7twCSL9wSfoyxMveJ

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
